@@ -17,11 +17,15 @@ replace_assignment = function(exp) {
   lapply(as.list(exp), codetools::walkCode, w = wc)
 }
 
-## mask comments to cheat R
-mask_comments = function(x, keep.blank.line, wrap, arrow, args.newline, spaces) {
+parse_data = function(x) {
   d = utils::getParseData(parse_source(x))
-  if (nrow(d) == 0 || (n <- sum(d$terminal)) == 0) return(x)
-  d = d[d$terminal, ]
+  d[d$terminal, ]
+}
+
+# mask comments in strings so that deparse() will not drop them
+mask_comments = function(x, keep.blank.line, wrap, arrow, args.newline, spaces) {
+  d = parse_data(x)
+  if ((n <- nrow(d)) == 0) return(x)
   d = fix_parse_data(d, x)
   if (args.newline) d = insert_arg_breaks(d, spaces)
   d.line = d$line1; d.line2 = d$line2; d.token = d$token; d.text = d$text
@@ -149,7 +153,7 @@ move_leftbrace = function(x) {
   x
 }
 
-# parse but do not keep source (moved from knitr)
+# parse but do not keep source (copied from xfun)
 parse_only = function(code) {
   if (length(code) == 0) return(expression())
   base::parse(text = code, keep.source = FALSE)
